==> haskell-warp-3.2.12-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.12
id: warp-3.2.12-JirNNL9JkiY5scISkptQgX
key: warp-3.2.12-JirNNL9JkiY5scISkptQgX
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
exposed: True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.File
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.IORef Network.Wai.Handler.Warp.PackInt
                Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
                Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Some
                Network.Wai.Handler.Warp.Timeout Network.Wai.Handler.Warp.Types
                Network.Wai.Handler.Warp.Windows
                Network.Wai.Handler.Warp.WithApplication Paths_warp
                Network.Wai.Handler.Warp.MultiMap
abi: 274659dcbcc36d32e2b16939612bc043
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/warp-3.2.12
library-dirs: /usr/lib/ghc-8.0.1/site-local/warp-3.2.12
data-dir: /usr/share/i386-linux-ghc-8.0.1/warp-3.2.12
hs-libraries: HSwarp-3.2.12-JirNNL9JkiY5scISkptQgX
depends:
    array-0.5.1.1 async-2.1.1.1-H3AbYkdNxWLAjCWaC7fyS4
    auto-update-0.1.4-GAesfFmqoZzBz6e09kRyzb base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.9-HR7ngNnTOX66jDpe7AgOeu containers-0.5.7.1
    ghc-prim-0.5.0.0 hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    http-date-0.0.6.1-Jpd6oqB2FgfHxNuwDmOMO1
    http-types-0.9.1-E37jBtYKNpTKS6SyGsLwFU
    http2-1.6.3-Kvpwsy2PHd8Jk4MaDHzHlq
    iproute-1.7.1-9hsGfRvggCmFA0ueZi5Sd9
    network-2.6.3.1-G4Up1CPKbp7DeFsnywOnGG
    simple-sendfile-0.2.25-DD8P3vuUuOYGeRr9aw9ky7
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    streaming-commons-0.1.17-6k51SJxMSKy6BYhtadRCnX
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ unix-2.7.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    vault-0.3.0.7-7ljhTnQetmMK9FZWfMdQzN
    wai-3.2.1.1-Em8S4AXb0sj2I3tvlcNzHV
    word8-0.1.2-2E1SgvvAV2fK8vZPDHbRan
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-3.2.12-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.12
id: warp-3.2.12-I48cwxl3zkoEHofxH09Q0X
key: warp-3.2.12-I48cwxl3zkoEHofxH09Q0X
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
exposed: True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.File
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.IORef Network.Wai.Handler.Warp.PackInt
                Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
                Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Some
                Network.Wai.Handler.Warp.Timeout Network.Wai.Handler.Warp.Types
                Network.Wai.Handler.Warp.Windows
                Network.Wai.Handler.Warp.WithApplication Paths_warp
                Network.Wai.Handler.Warp.MultiMap
abi: 74cd7eca8e78718cc0e1a2d166d323c2
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/warp-3.2.12
library-dirs: /usr/lib/ghc-8.0.2/site-local/warp-3.2.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/warp-3.2.12
hs-libraries: HSwarp-3.2.12-I48cwxl3zkoEHofxH09Q0X
depends:
    array-0.5.1.1 async-2.1.1.1-2GwQEYzLBsdIBCHbNA3HGy
    auto-update-0.1.4-EmUvNdmhEju51bHrtaEMpz base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO bytestring-0.10.8.1
    case-insensitive-1.2.0.10-3Sa52nt2lVR6gZGQE5fZZw containers-0.5.7.1
    ghc-prim-0.5.0.0 hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    http-date-0.0.6.1-4SuXvD5QkjeIzNDPiLBHb1
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    http2-1.6.3-97EqSxcQ6xM96dbyYX3qDp
    iproute-1.7.1-EJjAtfniBUorobFQnk7lR
    network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
    simple-sendfile-0.2.25-6OMSpqYXoFV3sBRuDlA99f
    stm-2.4.4.1-iSYwp3RMY11sHCifJ3gtR
    streaming-commons-0.1.18-KZl1SWhWop6Ksa4IiFWi6P
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq unix-2.7.2.1
    unix-compat-0.4.3.1-Ausmw6d7KIwA7sl52mzqxC
    vault-0.3.0.7-E4lXhyEMoKrEIYQFhBY3rZ
    wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    word8-0.1.2-9WDPGCTpW7JJnsiAQavtd1
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
